Continuous Signal
=================

Continuous Signal
-----------------

``colour.continuous``

.. currentmodule:: colour.continuous

.. autosummary::
    :toctree: generated/
    :template: class.rst

    AbstractContinuousFunction
    Signal
    MultiSignals
